@@ -19,6 +19,12 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
     echo_summary "Configuring Tempest"
     configure_osprofiler_in_tempest
 
+elif [[ "$1" == "unstack" ]]; then
+    if [[ "$OSPROFILER_COLLECTOR" == "jaeger" || \
+            "$OSPROFILER_COLLECTOR" == "otlp" ]]; then
+        echo_summary "Deleting jaeger docker container"
+        drop_jaeger
+    fi
 fi
 
 # Restore xtrace
